@@ -34,6 +34,8 @@ ENABLE_SERVER = 'ENABLE_SERVER'
 TEST_VALID_STATUS = "TEST_VALID_STATUS"
 TEST_ANONYMOUS = "TEST_ANONYMOUS"
 API_THREADED = "API_THREADED"
+KEEP_PROCESS_BAR_STYLE = "keep_process_bar_style"
+KEEP_PROCESS_BAR_STYLE_FILE = "keep_process_bar_style_file"
 
 """
 存储方式定义
