@@ -9,8 +9,8 @@ import csv
 import xlrd
 import xlwt
 
-from common_util import *
-from crawler_util import verify_rule
+from PaperCrawlerUtil.common_util import *
+from PaperCrawlerUtil.crawler_util import verify_rule
 
 
 class CsvProcess:
@@ -26,7 +26,6 @@ class CsvProcess:
         self.encoding = encoding
         self.mode = open_mode
         self.path = file_path
-        self.size = self.csv_size()
 
     def csv_size(self):
         """
