@@ -15,8 +15,8 @@ import execjs
 from googletrans import Translator
 from httpcore import SyncHTTPProxy
 
-from PaperCrawlerUtil import random_proxy_header_access
-from common_util import *
+from PaperCrawlerUtil.crawler_util import *
+from PaperCrawlerUtil.common_util import *
 
 
 def baidu_translate(string: str,
